##  Managing the Integration
  * Deactivate the integration: To temporarily deactivate the integration without deleting it, on the configuration page, choose the three-dot icon > Disable, then save the changes.
  * Reactivate the integration: To reactivate the integration, on the configuration page, choose the three-dot icon > Enable, then save the changes.
  * Delete the integration: To delete the integration, on the configuration page, choose the three-dot icon > Delete, then confirm your action. Deleting the integration deletes all configuration credentials, so proceed with caution.
